Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Driver ¶
type Driver interface {
Watch() <-chan *Payload
OnError(event *Payload, handlers ...OnErrorHandler)
}
Driver used as main interface to run supervisor activities
type OnErrorHandler ¶
type OnErrorHandler func(payload *Payload)
OnErrorHandler used as main type for handling plugin's error
type Payload ¶
Payload used as main data when some plugin from some host indicated as error / cannot be reached
type Runner ¶
type Runner struct {
// contains filtered or unexported fields
}
Runner is main struct to store supervisor's driver
func New ¶
func New(driver Driver, handlers ...OnErrorHandler) *Runner
New used to create new instance of supervisor
Click to show internal directories.
Click to hide internal directories.